@@ -1,5 +1,5 @@
 package Thrift::API::HiveClient2;
-$Thrift::API::HiveClient2::VERSION = '0.016';
+$Thrift::API::HiveClient2::VERSION = '0.017';
 {
   $Thrift::API::HiveClient2::DIST = 'Thrift-API-HiveClient2';
 }
@@ -11,7 +11,7 @@ use warnings;
 
 use Moo;
 use Carp;
-use Scalar::Util 'reftype';
+use Scalar::Util qw( reftype blessed );
 
 use Thrift;
 use Thrift::Socket;
@@ -72,9 +72,9 @@ sub _set_sasl {
     my ($self, $sasl) = @_;
     return if !$sasl;
 
+    # This normally selects XS first (hopefully)
     require Authen::SASL;
-    require Authen::SASL::XS;
-    Authen::SASL->import('XS');
+    Authen::SASL->import;
 
     require Thrift::SASL::Transport;
     Thrift::SASL::Transport->import;
@@ -83,7 +83,7 @@ sub _set_sasl {
         return $self->{_sasl} = Authen::SASL->new( mechanism => 'GSSAPI' );
     }
     elsif (reftype $sasl eq "HASH") {
-        return $self->{_sasl} = Authen::SASL->new( %$sasl );
+        return $self->{_sasl} = Authen::SASL->new( %$sasl ); #, debug => 8 );
     }
     die "Incorrect parameter passed to _set_sasl";
 }
@@ -143,7 +143,7 @@ has _session => (
     is      => 'rwp',
     isa     => sub {
         die "Session isn't a Thrift::API::HiveClient2::TOpenSessionResp"
-            if !$_[0]->isa('Thrift::API::HiveClient2::TOpenSessionResp') },
+            if ! blessed($_[0]) || !$_[0]->isa('Thrift::API::HiveClient2::TOpenSessionResp') },
     lazy    => 1,
     builder => '_build_session',
 );
@@ -151,7 +151,7 @@ has _session => (
 has username => (
     is      => 'rwp',
     lazy    => 1,
-    default => sub {'foo'},
+    default => sub { $ENV{USER} },
 );
 
 has password => (
@@ -176,7 +176,7 @@ has _session_handle => (
     is      => 'rwp',
     isa     => sub {
         die "Session handle isn't a Thrift::API::HiveClient2::TSessionHandle"
-            if !$_[0]->isa('Thrift::API::HiveClient2::TSessionHandle') },
+            if ! blessed($_[0]) || !$_[0]->isa('Thrift::API::HiveClient2::TSessionHandle') },
     lazy    => 1,
     builder => '_build_session_handle',
 );
@@ -190,7 +190,7 @@ has _operation => (
     is => "rwp",
     isa     => sub {
         die "Operation isn't a Thrift::API::HiveClient2::TExecuteStatementResp"
-            if defined $_[0] && !$_[0]->isa('Thrift::API::HiveClient2::TExecuteStatementResp') },
+            if defined $_[0] && ( ! blessed($_[0]) || !$_[0]->isa('Thrift::API::HiveClient2::TExecuteStatementResp') ) },
     lazy    => 1,
 );
 
@@ -199,7 +199,7 @@ has _operation_handle => (
     isa => sub {
         die
             "Operation handle isn't a Thrift::API::HiveClient2::TOperationHandle"
-            if defined $_[0] && !$_[0]->isa('Thrift::API::HiveClient2::TOperationHandle');
+            if defined $_[0] && ( ! blessed($_[0]) || !$_[0]->isa('Thrift::API::HiveClient2::TOperationHandle') );
     },
     lazy    => 1,
 );
@@ -353,7 +353,7 @@ Thrift::API::HiveClient2 - Perl to HiveServer2 Thrift API wrapper
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 METHODS
 
@@ -437,8 +437,8 @@ Authen::SASL, for instance:
     {
       mechanism  => 'PLAIN',
       callback   => {
-        user     => $USER,
-        password => "foobar",
+        canonuser => $USER, # not 'user', as I thought reading Authen::SASL's doc
+        password  => "foobar",
       }
     }
 
